@@ -1,4 +1,8 @@
+from typing import List, Dict
+
+
 class Product:
+    product_asin: str
     parent_asin: str
     weight: float
     brand: str
@@ -11,6 +15,13 @@ class Product:
     material: str
     description: list
     title: str
+    size_length: str
+    size_width: str
+    size_height: str
+    color: str
+    variation_values: Dict[str, list]
+    selected_variations: dict
+    asin_variation_values: List[dict]
 
     def __init__(self, attrs=None):
         self.__dict__ = attrs or dict()
