@@ -222,10 +222,11 @@ def parse_ship(p: Product, selector: parsel.Selector = None):
 
 def parse_delivery(p: Product, selector: parsel.Selector = None):
     delivery = selector.xpath("string(//div[@id='contextualIngressPtLabel_deliveryShortLine'])").get()
+    delivery = delivery or selector.xpath("normalize-space(//span[@id='glow-ingress-line2']/text())").get()
     if delivery is None:
         p.delivery = None
         return
-    if delivery == "Select delivery location":
+    if delivery in ["Select delivery location", "Select your address"]:
         p.delivery = "US"
         return
     if not delivery.startswith("Deliver to"):
